==> haskell-wl-pprint-terminfo-3.7.1.4-67-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-E6XMLabkqGyGRBKOnswtLp
key: wl-pprint-terminfo-3.7.1.4-E6XMLabkqGyGRBKOnswtLp
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: a6209c92cb4837186086458bd14e3d9f
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-E6XMLabkqGyGRBKOnswtLp
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    terminfo-0.4.1.1 text-1.2.3.0 transformers-0.5.5.0
    wl-pprint-extras-3.5.0.5-KQzQhpypizedx1zModT4Y
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             terminfo-0.4.1.1=f198095a593060871f229adb71186f33
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             wl-pprint-extras-3.5.0.5-KQzQhpypizedx1zModT4Y=5c3367ff464804476bf93167923e2f89
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-terminfo-3.7.1.4-68-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-4MdA5RUA75SDBeipmgdurZ
key: wl-pprint-terminfo-3.7.1.4-4MdA5RUA75SDBeipmgdurZ
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: f720ad00854502e27410834e00093350
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-4MdA5RUA75SDBeipmgdurZ
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    terminfo-0.4.1.1 text-1.2.3.0 transformers-0.5.5.0
    wl-pprint-extras-3.5.0.5-LwvdrmEmSCj8KK8NlBooIp
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             terminfo-0.4.1.1=f198095a593060871f229adb71186f33
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             wl-pprint-extras-3.5.0.5-LwvdrmEmSCj8KK8NlBooIp=6717b5e2f10402983e8996914b22dc06
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
